==> evolution-data-server-2.26.3-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libebook-1.2.so )
( cd usr/lib64 ; ln -sf libebook-1.2.so.9.3.0 libebook-1.2.so )
( cd usr/lib64 ; rm -rf libcamel-provider-1.2.so.14 )
( cd usr/lib64 ; ln -sf libcamel-provider-1.2.so.14.0.0 libcamel-provider-1.2.so.14 )
( cd usr/lib64 ; rm -rf libedata-book-1.2.so.2 )
( cd usr/lib64 ; ln -sf libedata-book-1.2.so.2.4.1 libedata-book-1.2.so.2 )
( cd usr/lib64 ; rm -rf libcamel-1.2.so )
( cd usr/lib64 ; ln -sf libcamel-1.2.so.14.0.0 libcamel-1.2.so )
( cd usr/lib64 ; rm -rf libedataserverui-1.2.so.8 )
( cd usr/lib64 ; ln -sf libedataserverui-1.2.so.8.1.0 libedataserverui-1.2.so.8 )
( cd usr/lib64 ; rm -rf libgdata-google-1.2.so.1 )
( cd usr/lib64 ; ln -sf libgdata-google-1.2.so.1.0.0 libgdata-google-1.2.so.1 )
( cd usr/lib64 ; rm -rf libcamel-1.2.so.14 )
( cd usr/lib64 ; ln -sf libcamel-1.2.so.14.0.0 libcamel-1.2.so.14 )
( cd usr/lib64 ; rm -rf libedataserverui-1.2.so )
( cd usr/lib64 ; ln -sf libedataserverui-1.2.so.8.1.0 libedataserverui-1.2.so )
( cd usr/lib64 ; rm -rf libebook-1.2.so.9 )
( cd usr/lib64 ; ln -sf libebook-1.2.so.9.3.0 libebook-1.2.so.9 )
( cd usr/lib64 ; rm -rf libebackend-1.2.so )
( cd usr/lib64 ; ln -sf libebackend-1.2.so.0.0.0 libebackend-1.2.so )
( cd usr/lib64 ; rm -rf libedata-cal-1.2.so.6 )
( cd usr/lib64 ; ln -sf libedata-cal-1.2.so.6.0.2 libedata-cal-1.2.so.6 )
( cd usr/lib64 ; rm -rf libegroupwise-1.2.so.13 )
( cd usr/lib64 ; ln -sf libegroupwise-1.2.so.13.0.1 libegroupwise-1.2.so.13 )
( cd usr/lib64 ; rm -rf libgdata-1.2.so.1 )
( cd usr/lib64 ; ln -sf libgdata-1.2.so.1.0.0 libgdata-1.2.so.1 )
( cd usr/lib64 ; rm -rf libedata-book-1.2.so )
( cd usr/lib64 ; ln -sf libedata-book-1.2.so.2.4.1 libedata-book-1.2.so )
( cd usr/lib64 ; rm -rf libgdata-1.2.so )
( cd usr/lib64 ; ln -sf libgdata-1.2.so.1.0.0 libgdata-1.2.so )
( cd usr/lib64 ; rm -rf libecal-1.2.so.7 )
( cd usr/lib64 ; ln -sf libecal-1.2.so.7.2.1 libecal-1.2.so.7 )
( cd usr/lib64 ; rm -rf libebackend-1.2.so.0 )
( cd usr/lib64 ; ln -sf libebackend-1.2.so.0.0.0 libebackend-1.2.so.0 )
( cd usr/lib64 ; rm -rf libcamel-provider-1.2.so )
( cd usr/lib64 ; ln -sf libcamel-provider-1.2.so.14.0.0 libcamel-provider-1.2.so )
( cd usr/lib64 ; rm -rf libedata-cal-1.2.so )
( cd usr/lib64 ; ln -sf libedata-cal-1.2.so.6.0.2 libedata-cal-1.2.so )
( cd usr/lib64 ; rm -rf libexchange-storage-1.2.so )
( cd usr/lib64 ; ln -sf libexchange-storage-1.2.so.3.0.0 libexchange-storage-1.2.so )
( cd usr/lib64 ; rm -rf libedataserver-1.2.so )
( cd usr/lib64 ; ln -sf libedataserver-1.2.so.11.0.0 libedataserver-1.2.so )
( cd usr/lib64 ; rm -rf libedataserver-1.2.so.11 )
( cd usr/lib64 ; ln -sf libedataserver-1.2.so.11.0.0 libedataserver-1.2.so.11 )
( cd usr/lib64 ; rm -rf libgdata-google-1.2.so )
( cd usr/lib64 ; ln -sf libgdata-google-1.2.so.1.0.0 libgdata-google-1.2.so )
( cd usr/lib64 ; rm -rf libexchange-storage-1.2.so.3 )
( cd usr/lib64 ; ln -sf libexchange-storage-1.2.so.3.0.0 libexchange-storage-1.2.so.3 )
( cd usr/lib64 ; rm -rf libegroupwise-1.2.so )
( cd usr/lib64 ; ln -sf libegroupwise-1.2.so.13.0.1 libegroupwise-1.2.so )
( cd usr/lib64 ; rm -rf libecal-1.2.so )
( cd usr/lib64 ; ln -sf libecal-1.2.so.7.2.1 libecal-1.2.so )

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

==> evolution-data-server-2.28.2-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libedata-book-1.2.so )
( cd usr/lib64 ; ln -sf libedata-book-1.2.so.2.4.1 libedata-book-1.2.so )
( cd usr/lib64 ; rm -rf libcamel-1.2.so.14 )
( cd usr/lib64 ; ln -sf libcamel-1.2.so.14.0.1 libcamel-1.2.so.14 )
( cd usr/lib64 ; rm -rf libcamel-1.2.so )
( cd usr/lib64 ; ln -sf libcamel-1.2.so.14.0.1 libcamel-1.2.so )
( cd usr/lib64 ; rm -rf libgdata-google-1.2.so )
( cd usr/lib64 ; ln -sf libgdata-google-1.2.so.1.0.0 libgdata-google-1.2.so )
( cd usr/lib64 ; rm -rf libedata-cal-1.2.so.6 )
( cd usr/lib64 ; ln -sf libedata-cal-1.2.so.6.0.2 libedata-cal-1.2.so.6 )
( cd usr/lib64 ; rm -rf libecal-1.2.so.7 )
( cd usr/lib64 ; ln -sf libecal-1.2.so.7.2.2 libecal-1.2.so.7 )
( cd usr/lib64 ; rm -rf libexchange-storage-1.2.so.3 )
( cd usr/lib64 ; ln -sf libexchange-storage-1.2.so.3.0.0 libexchange-storage-1.2.so.3 )
( cd usr/lib64 ; rm -rf libegroupwise-1.2.so )
( cd usr/lib64 ; ln -sf libegroupwise-1.2.so.13.0.1 libegroupwise-1.2.so )
( cd usr/lib64 ; rm -rf libebackend-1.2.so )
( cd usr/lib64 ; ln -sf libebackend-1.2.so.0.0.1 libebackend-1.2.so )
( cd usr/lib64 ; rm -rf libedataserver-1.2.so )
( cd usr/lib64 ; ln -sf libedataserver-1.2.so.11.0.1 libedataserver-1.2.so )
( cd usr/lib64 ; rm -rf libgdata-google-1.2.so.1 )
( cd usr/lib64 ; ln -sf libgdata-google-1.2.so.1.0.0 libgdata-google-1.2.so.1 )
( cd usr/lib64 ; rm -rf libedataserverui-1.2.so.8 )
( cd usr/lib64 ; ln -sf libedataserverui-1.2.so.8.1.1 libedataserverui-1.2.so.8 )
( cd usr/lib64 ; rm -rf libebackend-1.2.so.0 )
( cd usr/lib64 ; ln -sf libebackend-1.2.so.0.0.1 libebackend-1.2.so.0 )
( cd usr/lib64 ; rm -rf libecal-1.2.so )
( cd usr/lib64 ; ln -sf libecal-1.2.so.7.2.2 libecal-1.2.so )
( cd usr/lib64 ; rm -rf libedataserver-1.2.so.11 )
( cd usr/lib64 ; ln -sf libedataserver-1.2.so.11.0.1 libedataserver-1.2.so.11 )
( cd usr/lib64 ; rm -rf libcamel-provider-1.2.so )
( cd usr/lib64 ; ln -sf libcamel-provider-1.2.so.14.0.1 libcamel-provider-1.2.so )
( cd usr/lib64 ; rm -rf libebook-1.2.so )
( cd usr/lib64 ; ln -sf libebook-1.2.so.9.3.1 libebook-1.2.so )
( cd usr/lib64 ; rm -rf libebook-1.2.so.9 )
( cd usr/lib64 ; ln -sf libebook-1.2.so.9.3.1 libebook-1.2.so.9 )
( cd usr/lib64 ; rm -rf libedata-book-1.2.so.2 )
( cd usr/lib64 ; ln -sf libedata-book-1.2.so.2.4.1 libedata-book-1.2.so.2 )
( cd usr/lib64 ; rm -rf libegroupwise-1.2.so.13 )
( cd usr/lib64 ; ln -sf libegroupwise-1.2.so.13.0.1 libegroupwise-1.2.so.13 )
( cd usr/lib64 ; rm -rf libedataserverui-1.2.so )
( cd usr/lib64 ; ln -sf libedataserverui-1.2.so.8.1.1 libedataserverui-1.2.so )
( cd usr/lib64 ; rm -rf libgdata-1.2.so.1 )
( cd usr/lib64 ; ln -sf libgdata-1.2.so.1.0.0 libgdata-1.2.so.1 )
( cd usr/lib64 ; rm -rf libexchange-storage-1.2.so )
( cd usr/lib64 ; ln -sf libexchange-storage-1.2.so.3.0.0 libexchange-storage-1.2.so )
( cd usr/lib64 ; rm -rf libedata-cal-1.2.so )
( cd usr/lib64 ; ln -sf libedata-cal-1.2.so.6.0.2 libedata-cal-1.2.so )
( cd usr/lib64 ; rm -rf libgdata-1.2.so )
( cd usr/lib64 ; ln -sf libgdata-1.2.so.1.0.0 libgdata-1.2.so )
( cd usr/lib64 ; rm -rf libcamel-provider-1.2.so.14 )
( cd usr/lib64 ; ln -sf libcamel-provider-1.2.so.14.0.1 libcamel-provider-1.2.so.14 )

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
